Enum PaymentType

#[non_exhaustive]
pub enum PaymentType { AttachedCycles, CallerPaysIcrc2Cycles, PatronPaysIcrc2Cycles(PatronPaysIcrc2Cycles), CallerPaysIcrc2Tokens(CallerPaysIcrc2Tokens), PatronPaysIcrc2Tokens(PatronPaysIcrc2Tokens), }
How a caller states that they will pay.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AttachedCycles

The caller is paying with cycles attached to the call.

Note: This is available to inter-canister aclls only; not to ingress messages.

Note: The API does not require additional arguments to support this payment type.



CallerPaysIcrc2Cycles

The caller is paying with cycles from their main account on the cycles ledger.



PatronPaysIcrc2Cycles(PatronPaysIcrc2Cycles)

A patron is paying with cycles on behalf of the caller.



CallerPaysIcrc2Tokens(CallerPaysIcrc2Tokens)

The caller is paying with tokens from their main account on the specified ledger.



PatronPaysIcrc2Tokens(PatronPaysIcrc2Tokens)

A patron is paying, on behalf of the caller, from an account on the specified ledger.