Enum PaymentOption

#[non_exhaustive]
pub enum PaymentOption { AttachedCycles { fee: Option<TokenAmount>, }, CallerPaysIcrc2Cycles { fee: Option<TokenAmount>, }, PatronPaysIcrc2Cycles { fee: Option<TokenAmount>, }, }
Billing options that may be offered to a customer.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AttachedCycles

The caller is paying with cycles attached to the call.

Note: This is available to inter-canister aclls only; not to ingress messages.

Note: The API does not require additional arguments to support this payment type.

Fields



CallerPaysIcrc2Cycles

The caller is paying with cycles from their main account on the cycles ledger.

Fields



PatronPaysIcrc2Cycles

A patron is paying, on behalf of the caller, from their main account on the cycles ledger.

Fields