Icrc2Payer

Struct Icrc2Payer 

pub struct Icrc2Payer {
    pub account: Option<Account>,
    pub spender_subaccount: Option<ByteBuf>,
    pub ledger_canister_id: Option<Principal>,
    pub created_at_time: Option<TokenAmount>,
}
User’s payment details for an ICRC2 payment.

Fields

account: Option<Account>

The customer’s principal and (optionally) subaccount.

By default, the caller’s main account is used.

spender_subaccount: Option<ByteBuf>

The spender, if different from the payer.

ledger_canister_id: Option<Principal>

The ledger canister ID.

Note: This is included in order to improve error messages if the caller tries to use the wrong ledger.

created_at_time: Option<TokenAmount>

Corresponds to the created_at_time field in ICRC2.