#[non_exhaustive]pub enum PaymentOption {
AttachedCycles {
fee: Option<TokenAmount>,
},
CallerPaysIcrc2Cycles {
fee: Option<TokenAmount>,
},
PatronPaysIcrc2Cycles {
fee: Option<TokenAmount>,
},
}Expand description
Billing options that may be offered to a customer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AttachedCycles
The caller is paying with cycles attached to the call.
Note: This is available to inter-canister aclls only; not to ingress messages.
Note: The API does not require additional arguments to support this payment type.
Fields

fee: Option<TokenAmount>CallerPaysIcrc2Cycles
The caller is paying with cycles from their main account on the cycles ledger.
Fields

fee: Option<TokenAmount>PatronPaysIcrc2Cycles
A patron is paying, on behalf of the caller, from their main account on the cycles ledger.
Fields

fee: Option<TokenAmount>Trait Implementations
Sourceimpl CandidType for PaymentOption
impl CandidType for PaymentOption
Sourceimpl Clone for PaymentOption
impl Clone for PaymentOption
Sourcefn clone(&self) -> PaymentOption
fn clone(&self) -> PaymentOption
Returns a duplicate of the value. Read more
1.0.0 · Sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PaymentOption
impl Debug for PaymentOption
Sourceimpl<'de> Deserialize<'de> for PaymentOption
impl<'de> Deserialize<'de> for PaymentOption
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PaymentOption
impl PartialEq for PaymentOption
impl Copy for PaymentOption
impl Eq for PaymentOption
impl StructuralPartialEq for PaymentOption